==> haskell-zlib-bindings-0.1.1.5-143-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zlib-bindings.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zlib-bindings
version:              0.1.1.5
visibility:           public
id:                   zlib-bindings-0.1.1.5-GmeOI6Y1FPk3HgNwXmynnR
key:                  zlib-bindings-0.1.1.5-GmeOI6Y1FPk3HgNwXmynnR
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Experimental
homepage:             http://github.com/snoyberg/zlib-bindings
synopsis:             Low-level bindings to the zlib package. (deprecated)
description:          Deprecated in favor of streaming-commons
category:             Codec
abi:                  cbea59477b8af6dd44f7519e1372f7f0
exposed:              True
exposed-modules:      Codec.Zlib Codec.Zlib.Lowlevel
import-dirs:          /usr/lib/ghc-9.0.2/site-local/zlib-bindings-0.1.1.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/zlib-bindings-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zlib-bindings
hs-libraries:         HSzlib-bindings-0.1.1.5-GmeOI6Y1FPk3HgNwXmynnR
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    zlib-0.6.3.0-KGB6WSQ4p2xLPLJOOhe04c

haddock-interfaces:
    /usr/share/doc/haskell-zlib-bindings/html/zlib-bindings.haddock

haddock-html:         /usr/share/doc/haskell-zlib-bindings/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-zlib-bindings-0.1.1.5-154-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-zlib-bindings.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 zlib-bindings
version:              0.1.1.5
visibility:           public
id:                   zlib-bindings-0.1.1.5-1Cyc1zZ7Bl5KnBr1vrnUnx
key:                  zlib-bindings-0.1.1.5-1Cyc1zZ7Bl5KnBr1vrnUnx
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:               Michael Snoyman <michael@snoyman.com>
stability:            Experimental
homepage:             http://github.com/snoyberg/zlib-bindings
synopsis:             Low-level bindings to the zlib package. (deprecated)
description:          Deprecated in favor of streaming-commons
category:             Codec
abi:                  084d1d71c470a9f37ae841d8a5473e51
exposed:              True
exposed-modules:      Codec.Zlib Codec.Zlib.Lowlevel
import-dirs:          /usr/lib/ghc-9.0.2/site-local/zlib-bindings-0.1.1.5
library-dirs:         /usr/lib/ghc-9.0.2/site-local/zlib-bindings-0.1.1.5
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-zlib-bindings
hs-libraries:         HSzlib-bindings-0.1.1.5-1Cyc1zZ7Bl5KnBr1vrnUnx
depends:
    base-4.15.1.0 bytestring-0.10.12.1
    zlib-0.6.3.0-7dyta8qtrVeTN5i5Nwtef

haddock-interfaces:
    /usr/share/doc/haskell-zlib-bindings/html/zlib-bindings.haddock

haddock-html:         /usr/share/doc/haskell-zlib-bindings/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
